@@ -8,9 +8,10 @@
  *
  * ----
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public
- * License version 2 as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,13 +24,12 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
-#include <QPixmap>
-#include <QSize>
-#include <QWidget>
-#include <QColor>
-#include <QPaintEvent>
-#include <kurl.h>
+#include <QtGui/QPixmap>
+#include <QtCore/QSize>
+#include <QtGui/QWidget>
+#include <QtGui/QColor>
+#include <QtGui/QPaintEvent>
+#include <KDE/KUrl>
 #include "KfiConstants.h"
 #include "FcEngine.h"
 
