@@ -8,31 +8,20 @@
 
 ****************************************************************************/
 
-#define _KHOTKEYS_KDED_CPP_
-
-#include <config-workspace.h>
-
 #include "kded.h"
 
+#include "action_data.h"
+#include "gestures.h"
+#include "khotkeysadaptor.h"
+#include "settings.h"
+
+#include <kdebug.h>
+
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
-#include <klocale.h>
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <unistd.h>
 
-#include <X11/Xlib.h>
-#include <fixx11h.h>
-
-#include <settings.h>
-#include <input.h>
-#include <action_data.h>
-#include <gestures.h>
-#include <voices.h>
-
-#include "khotkeysadaptor.h"
-
 K_PLUGIN_FACTORY(KHotKeysModuleFactory,
                  registerPlugin<KHotKeysModule>();
     )
@@ -56,6 +45,7 @@ KHotKeysModule::KHotKeysModule(QObject* parent, const QList<QVariant>&)
             sleep( 1 );
             }
         }
+    QDBusConnection::sessionBus().registerService( "org.kde.khotkeys" );
     QDBusConnection::sessionBus().registerObject("/KHotKeys", this);
     KHotKeys::init_global_data( true, this ); // grab keys
     // CHECKME triggery a dalsi vytvaret az tady za inicializaci
@@ -67,6 +57,7 @@ KHotKeysModule::~KHotKeysModule()
     {
     // CHECKME triggery a dalsi rusit uz tady pred cleanupem
     delete actions_root;
+    QDBusConnection::sessionBus().unregisterService( "org.kde.khotkeys" );
     }
 
 void KHotKeysModule::reread_configuration()
@@ -76,15 +67,16 @@ void KHotKeysModule::reread_configuration()
     KHotKeys::khotkeys_set_active( false );
     KHotKeys::Settings settings;
     settings.read_settings( false );
-    KHotKeys::gesture_handler->set_mouse_button( settings.gesture_mouse_button );
-    KHotKeys::gesture_handler->set_timeout( settings.gesture_timeout );
-    KHotKeys::gesture_handler->enable( !settings.gestures_disabled_globally );
-    KHotKeys::gesture_handler->set_exclude( settings.gestures_exclude );
-    KHotKeys::voice_handler->set_shortcut( settings.voice_shortcut );
+    KHotKeys::gesture_handler->set_mouse_button( settings.gestureMouseButton() );
+    KHotKeys::gesture_handler->set_timeout( settings.gestureTimeOut() );
+    KHotKeys::gesture_handler->enable( !settings.areGesturesDisabled() );
+    KHotKeys::gesture_handler->set_exclude( settings.gesturesExclude() );
+    // FIXME: SOUND
+    // KHotKeys::voice_handler->set_shortcut( settings.voice_shortcut );
 #if 0 // TEST CHECKME
     settings.write_settings();
 #endif
-    actions_root = settings.actions;
+    actions_root = settings.takeActions();
     KHotKeys::khotkeys_set_active( true );
     actions_root->update_triggers();
     }
