@@ -38,14 +38,15 @@ namespace KHotKeys
 // Action_list_widget
 
 Action_list_widget::Action_list_widget( QWidget* parent_P, const char* name_P )
-    : Action_list_widget_ui( parent_P, name_P ), selected_item( NULL )
+    : Action_list_widget_ui( parent_P ), selected_item( NULL )
     {
+    setObjectName(name_P);
     QMenu* popup = new QMenu; // CHECKME looks like setting parent doesn't work
     QAction *action = popup->addAction( i18n( "Command/URL..." ) );
     action->setData( TYPE_COMMAND_URL_ACTION );
     action = popup->addAction( i18n( "K-Menu Entry..." ) );
     action->setData( TYPE_MENUENTRY_ACTION );
-    action = popup->addAction( i18n( "DCOP Call..." ) );
+    action = popup->addAction( i18n( "D-Bus Call..." ) );
     action->setData( TYPE_DBUS_ACTION );
     action = popup->addAction( i18n( "Keyboard Input..." ) );
     action->setData( TYPE_KEYBOARD_INPUT_ACTION );
@@ -63,6 +64,10 @@ Action_list_widget::Action_list_widget( QWidget* parent_P, const char* name_P )
     clear_data();
     connect( actions_listview, SIGNAL( doubleClicked ( Q3ListViewItem *, const QPoint &, int ) ),
              this, SLOT( modify_pressed() ) );
+    connect( copy_button,SIGNAL(clicked()),this,SLOT(copy_pressed()));
+    connect(modify_button ,SIGNAL(clicked()),this,SLOT(modify_pressed()));
+    connect(delete_button,SIGNAL(clicked()),this,SLOT(delete_pressed()));
+    connect(actions_listview,SIGNAL(current_changed(Q3ListViewItem*)),this,SLOT(current_changed(Q3ListViewItem*)));
 
     // KHotKeys::Module::changed()
     connect( new_button, SIGNAL( clicked()),
@@ -98,10 +103,12 @@ void Action_list_widget::set_data( const Action_list* data_P )
     comment_lineedit->setText( data_P->comment());
     Action_list_item* after = NULL;
     actions_listview->clear();
-    for( Action_list::Iterator it( *data_P );
-         *it;
+    for( Action_list::ConstIterator it = data_P->begin();
+         it != data_P->end();
          ++it )
+        {
         after = create_listview_item( *it, actions_listview, NULL, after, true );
+        }
     }
 
 Action_list* Action_list_widget::get_data( Action_data* data_P ) const
