@@ -14,6 +14,7 @@
 
 #include "kcmkhotkeys.h"
 #include "khotkeysiface.h"
+#include <KDE/KGlobalAccel>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -68,7 +69,7 @@ extern "C"
     else
         {
         QDBusInterface kded("org.kde.kded", "/kded", "org.kde.kded");
-		QDBusReply<bool> reply = kded.call("loadModule",QString( "khotkeys" ) );
+        QDBusReply<bool> reply = kded.call("loadModule",QString( "khotkeys" ) );
         if( !reply.isValid())
             {
             kWarning( 1217 ) << "Loading of khotkeys module failed." ;
@@ -85,6 +86,8 @@ Module::Module( QWidget* parent_P, const QVariantList & )
     : KCModule( KHotKeysFactory::componentData(), parent_P ), _actions_root( NULL ), _current_action_data( NULL ),
         listview_is_changed( false ), deleting_action( false )
     {
+    KGlobalAccel::self()->overrideMainComponentData(KComponentData("khotkeys"));
+
     setButtons( Apply );
     module = this;
     init_global_data( false, this ); // don't grab keys
@@ -110,10 +113,8 @@ Module::Module( QWidget* parent_P, const QVariantList & )
     connect( buttons_widget, SIGNAL( global_settings_pressed()), SLOT( global_settings()));
 //    listview_current_action_changed(); // init
 
-		KAboutData* about = new KAboutData("kcmkhotkeys", 0, ki18n("KHotKeys"), KHOTKEYS_VERSION,
-      KLocalizedString(),
-      KAboutData::License_GPL,
-      ki18n("(c) 1999-2005 Lubos Lunak"));
+    KAboutData* about = new KAboutData("kcmkhotkeys", 0, ki18n("KHotKeys"), KHOTKEYS_VERSION,
+        KLocalizedString(), KAboutData::License_GPL, ki18n("(c) 1999-2005 Lubos Lunak"));
     about->addAuthor(ki18n("Lubos Lunak"), ki18n("Maintainer"), "l.lunak@kde.org");
     setAboutData( about );
     load();
@@ -123,18 +124,16 @@ Module::~Module()
     {
     _current_action_data = NULL;
     tab_widget->load_current_action(); // clear tab_widget
-    delete _actions_root;
     module = NULL;
     }
 
 void Module::load()
     {
     actions_listview_widget->clear();
-    delete _actions_root;
-    settings.actions = NULL;
+    settings.setActions(0);
     _current_action_data = NULL;
     settings.read_settings( true );
-    _actions_root = settings.actions;
+    _actions_root = settings.actions();
     kDebug( 1217 ) << "actions_root:" << _actions_root;
     actions_listview_widget->build_up();
     tab_widget->load_current_action();
@@ -144,7 +143,6 @@ void Module::load()
 void Module::save()
     {
     tab_widget->save_current_action_changes();
-    settings.actions = _actions_root;
     kDebug(1217) << "Storing actions" << _actions_root;
     settings.write_settings();
     QDBusConnection bus = QDBusConnection::sessionBus();
@@ -300,20 +298,19 @@ void Module::global_settings()
 
 void Module::set_gestures_exclude( Windowdef_list* windows )
     {
-    delete settings.gestures_exclude;
-    settings.gestures_exclude = windows;
+    settings.setGesturesExclude( windows );
     }
 
 void Module::import()
     {
-    QString file = KFileDialog::getOpenFileName( QString(), "*.khotkeys", topLevelWidget(),
+    QString file = KFileDialog::getOpenFileName( QString(), "*.khotkeys", window(),
         i18n( "Select File with Actions to Be Imported" ));
     if( file.isEmpty())
         return;
     KConfig cfg(  file, KConfig::SimpleConfig);
     if( !settings.import( cfg, true ))
         {
-        KMessageBox::error( topLevelWidget(),
+        KMessageBox::error( window(),
             i18n( "Import of the specified file failed. Most probably the file is not a valid "
                 "file with actions." ));
         return;
