@@ -13,6 +13,7 @@
 #include <config-khotkeys.h>
 
 #include "triggers_tab.h"
+#include "action_data.h"
 
 #include <assert.h>
 #include <QPushButton>
@@ -43,9 +44,9 @@ namespace KHotKeys
 // Triggers_tab
 
 Triggers_tab::Triggers_tab( QWidget* parent_P, const char* name_P )
-    : Triggers_tab_ui( parent_P, name_P ), selected_item( NULL )
+    : Triggers_tab_ui( parent_P ), selected_item( NULL )
     {
-
+    setObjectName(name_P);
     QMenu* popup = new QMenu; // CHECKME looks like setting parent doesn't work
     QAction *action = popup->addAction( i18n( "Shortcut Trigger..." ) );
     action->setData( TYPE_SHORTCUT_TRIGGER );
@@ -68,6 +69,10 @@ Triggers_tab::Triggers_tab( QWidget* parent_P, const char* name_P )
     connect( popup, SIGNAL( triggered( QAction* )), SLOT( new_selected( QAction* )));
     connect( triggers_listview, SIGNAL( doubleClicked ( Q3ListViewItem *, const QPoint &, int ) ),
              this, SLOT( modify_pressed() ) );
+    connect(modify_button, SIGNAL(clicked()),this,SLOT(modify_pressed()));
+    connect(delete_button, SIGNAL(clicked()),this,SLOT(delete_pressed()));
+    connect(copy_button, SIGNAL(clicked()),this,SLOT(copy_pressed()));
+    connect(triggers_listview,SIGNAL(current_changed(Q3ListViewItem*)),this,SLOT(current_changed(Q3ListViewItem*)));
 
     new_button->setMenu( popup );
     copy_button->setEnabled( false );
@@ -112,10 +117,12 @@ void Triggers_tab::set_data( const Trigger_list* data_P )
     comment_lineedit->setText( data_P->comment());
     Trigger_list_item* after = NULL;
     triggers_listview->clear();
-    for( Trigger_list::Iterator it( *data_P );
-         *it;
+    for( Trigger_list::ConstIterator it = data_P->begin();
+         it != data_P->end();
          ++it )
+        {
         after = create_listview_item( *it, triggers_listview, after, true );
+        }
     }
 
 Trigger_list* Triggers_tab::get_data( Action_data* data_P ) const
@@ -137,7 +144,7 @@ void Triggers_tab::new_selected( QAction *action )
         {
         case TYPE_SHORTCUT_TRIGGER: // Shortcut_trigger
             dlg = new Shortcut_trigger_dialog(
-                new Shortcut_trigger( NULL, KShortcut())); // CHECKME NULL ?
+                new Shortcut_trigger( NULL, i18n("TODO: Correct Behavior" ), KShortcut())); // CHECKME NULL ?
           break;
         case TYPE_GESTURE_TRIGGER: // Gesture trigger
             dlg = new Gesture_trigger_dialog(
@@ -147,9 +154,12 @@ void Triggers_tab::new_selected( QAction *action )
             dlg = new Window_trigger_dialog( new Window_trigger( NULL, new Windowdef_list( "" ),
                 0 )); // CHECKME NULL ?
           break;
+// FIXME: SOUND
+#if 0
         case TYPE_VOICE_TRIGGER: // Voice trigger
 			dlg = new Voice_trigger_dialog( new Voice_trigger(NULL,QString(),VoiceSignature(),VoiceSignature())); // CHECKME NULL ?
 			break;
+#endif
         }
     if( dlg != NULL )
         {
@@ -211,8 +221,11 @@ void Triggers_tab::edit_listview_item( Trigger_list_item* item_P )
         dlg = new Gesture_trigger_dialog( trg );
     else if( Window_trigger* trg = dynamic_cast< Window_trigger* >( item_P->trigger()))
         dlg = new Window_trigger_dialog( trg );
+// FIXME: SOUND
+#if 0
     else if( Voice_trigger* trg = dynamic_cast< Voice_trigger* >( item_P->trigger()))
         dlg = new Voice_trigger_dialog( trg );
+#endif
 // CHECKME TODO dalsi
     else
         assert( false );
@@ -255,8 +268,8 @@ void Shortcut_trigger_widget::clear_data()
 
 void Shortcut_trigger_widget::capturedShortcut( const QKeySequence& s_P )
     {
-    /*if( KKeyChooser::checkGlobalShortcutsConflict( s_P, true, topLevelWidget())
-        || KKeyChooser::checkStandardShortcutsConflict( s_P, true, topLevelWidget()))
+    /*if( KKeyChooser::checkGlobalShortcutsConflict( s_P, true, window())
+        || KKeyChooser::checkStandardShortcutsConflict( s_P, true, window()))
         return;*/
     // KHotKeys::Module::changed()
     module->changed();
@@ -275,7 +288,7 @@ void Shortcut_trigger_widget::set_data( const Shortcut_trigger* data_P )
 
 Shortcut_trigger* Shortcut_trigger_widget::get_data( Action_data* data_P ) const
     {
-    return new Shortcut_trigger( data_P, KShortcut( ksw->keySequence() ) );
+    return new Shortcut_trigger( data_P, data_P->name(), KShortcut( ksw->keySequence() ) );
     }
 
 // Shortcut_trigger_dialog
@@ -354,6 +367,8 @@ Trigger* Gesture_trigger_dialog::edit_trigger()
     }
 
 
+// FIXME: SOUND
+#if 0
 // Voice_trigger_dialog
 
 Voice_trigger_dialog::Voice_trigger_dialog( Voice_trigger* trigger_P )
@@ -379,7 +394,7 @@ Trigger* Voice_trigger_dialog::edit_trigger()
 	else
 		return NULL;
 }
-
+#endif 
 
 
 
