@@ -16,9 +16,7 @@
 #include <QHBoxLayout>
 
 #include <kaboutdata.h>
-#define KDE3_SUPPORT
 #include <kcmodule.h>
-#undef KDE3_SUPPORT
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
@@ -80,7 +78,7 @@ KSplashThemeMgr::KSplashThemeMgr( QWidget *parent, const QVariantList &args)
   // Once string freeze is over, replace second argument with "Icon"
   about->addCredit(ki18n("Hans Karlsson"), KLocalizedString(), "karlsson.h@home.se" );
   setAboutData(about);
-  setButtons( KCModule::Default|KCModule::Apply );
+  //setButtons( KCModule::Default|KCModule::Apply );
 }
 
 KSplashThemeMgr::~KSplashThemeMgr()
