@@ -27,17 +27,19 @@
 // #ifndef OXYGENCLIENT_H
 // #define OXYGENCLIENT_H
 
+#include "oxygenclient.h"
+
 #include <KConfig>
 #include <KGlobal>
 #include <KLocale>
 #include <KDebug>
 #include <KColorUtils>
 
-#include <qbitmap.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpainter.h>
-#include <qtooltip.h>
+#include <QBitmap>
+#include <QLabel>
+#include <QLayout>
+#include <QPainter>
+#include <QToolTip>
 //Added by qt3to4:
 #include <QBoxLayout>
 #include <QGridLayout>
@@ -52,7 +54,6 @@
 
 #include "math.h"
 
-#include "oxygenclient.h"
 #include "oxygenclient.moc"
 #include "oxygenbutton.h"
 #include "oxygen.h"
@@ -88,8 +89,6 @@ void OxygenClient::init()
     KCommonDecoration::init();
 
     widget()->setAutoFillBackground(false);
-    widget()->setAttribute(Qt::WA_OpaquePaintEvent);
-    widget()->setAttribute(Qt::WA_PaintOnScreen, false);
 }
 
 bool OxygenClient::decorationBehaviour(DecorationBehaviour behaviour) const
@@ -190,10 +189,16 @@ KCommonDecorationButton *OxygenClient::createButton(::ButtonType type)
 
         case CloseButton:
             return new OxygenButton(*this, i18n("Close"), ButtonClose);
-/*
+
+        case AboveButton:
+            return new OxygenButton(*this, i18n("Keep Above Others"), ButtonAbove);
+
+        case BelowButton:
+            return new OxygenButton(*this, i18n("Keep Below Others"), ButtonBelow);
+
         case OnAllDesktopsButton:
-            return new OxygenButton(*this, i18n("All Desktops"), ButtonSticky);
-*/
+            return new OxygenButton(*this, i18n("On All Desktops"), ButtonSticky);
+
         default:
             return 0;
     }
@@ -251,6 +256,8 @@ void OxygenClient::paintEvent(QPaintEvent *e)
     Q_UNUSED(e)
     if (!OxygenFactory::initialized()) return;
 
+    updateButtons();
+
     QPalette palette = widget()->palette();
     QPainter painter(widget());
 
@@ -264,6 +271,8 @@ void OxygenClient::paintEvent(QPaintEvent *e)
     int x,y,w,h;
     QRect frame = widget()->frameGeometry();
     QColor color = palette.window().color();
+    QColor light = helper_.calcLightColor( color );
+    QColor dark = helper_.calcDarkColor( color );
 
     const int titleHeight = layoutMetric(LM_TitleHeight);
     const int titleTop = layoutMetric(LM_TitleEdgeTop) + frame.top();
@@ -277,30 +286,9 @@ void OxygenClient::paintEvent(QPaintEvent *e)
             buttonsLeftWidth() - buttonsRightWidth() -
             marginLeft - marginRight;
 
-
-    int splitY = qMin(300, 3*frame.height()/4);
-
-    QPixmap tile = helper_.verticalGradient(color, splitY);
-    painter.drawTiledPixmap(QRect(0, 0, frame.width(), titleHeight + TFRAMESIZE), tile);
-
-    painter.drawTiledPixmap(QRect(0, 0, LFRAMESIZE, splitY), tile);
-    painter.fillRect(0, splitY, LFRAMESIZE, frame.height() - splitY, helper_.backgroundBottomColor(color));
-
-    painter.drawTiledPixmap(QRect(frame.width()-RFRAMESIZE, 0,
-                                                        RFRAMESIZE, splitY), tile,
-                                                        QPoint(frame.width()-RFRAMESIZE, 0));
-    painter.fillRect(frame.width()-RFRAMESIZE, splitY, RFRAMESIZE, frame.height() - splitY, helper_.backgroundBottomColor(color));
-
-    painter.fillRect(0, frame.height() - BFRAMESIZE, frame.width(), BFRAMESIZE, helper_.backgroundBottomColor(color));
-
-    int radialW = qMin(600, frame.width() - LFRAMESIZE - RFRAMESIZE);
-    tile = helper_.radialGradient(color, radialW);
-    // In the style we assume the top frame to have a height of 32 this we need offset here with the
-    // actual value
-    int frameTopFixer = titleTop+titleHeight - 32;
-    QRect radialRect = QRect((frame.width() - radialW) / 2, frameTopFixer, radialW, 64);
-    painter.drawPixmap(radialRect, tile);
-
+    // draw window background
+    helper_.renderWindowBackground(&painter, frame, this->widget(), palette, 0);
+    
     // draw title text
     painter.setFont(options()->font(isActive(), false));
     painter.setPen(titlebarTextColor(palette));
@@ -314,34 +302,61 @@ void OxygenClient::paintEvent(QPaintEvent *e)
     frame.adjust(1,1,-1,-1);
     frame.getRect(&x, &y, &w, &h);
 
-    QColor light = helper_.calcLightColor(color);
-    QColor dark = helper_.calcDarkColor(color);
     dark.setAlpha(120);
 
-    if(!isActive()) {
-        light.setAlpha(120);
-        dark.setAlpha(50);
+    if(isActive()) {
+        QLinearGradient lg(x,0,x+w,0);
+        lg.setColorAt(0.5, dark);
+        dark.setAlpha(0);
+        lg.setColorAt(0.0, dark);
+        lg.setColorAt(1.0, dark);
+        painter.setPen(QPen(lg,1));
+
+        painter.drawLine(QPointF(x, titleTop+titleHeight-1.5),
+                                QPointF(x+w, titleTop+titleHeight-1.5));
+
+        lg = QLinearGradient(x,0,x+w,0);
+        lg.setColorAt(0.5, light);
+        light.setAlpha(0);
+        lg.setColorAt(0.0, light);
+        lg.setColorAt(1.0, light);
+        painter.setPen(QPen(lg,1));
+
+        painter.drawLine(QPointF(x, titleTop+titleHeight-0.5),
+                               QPointF(x+w, titleTop+titleHeight-0.5));
     }
 
-    QLinearGradient lg(x,0,x+w,0);
-    lg.setColorAt(0.5, dark);
-    dark.setAlpha(0);
-    lg.setColorAt(0.0, dark);
-    lg.setColorAt(1.0, dark);
-    painter.setPen(QPen(lg,1));
+    // draw stripes as indicator for active windows
+    if (isActive() && OxygenFactory::showStripes()) {
+        Qt::Alignment align = OxygenFactory::titleAlign();
+        if (widget()->layoutDirection() == Qt::RightToLeft)
+        {
+            if (align == Qt::AlignLeft)
+                align = Qt::AlignRight;
+            else if (align == Qt::AlignRight)
+                align = Qt::AlignLeft;
+        }
 
-    painter.drawLine(QPointF(x, titleTop+titleHeight-1.5),
-                            QPointF(x+w, titleTop+titleHeight-1.5));
-
-    lg = QLinearGradient(x,0,x+w,0);
-    lg.setColorAt(0.5, light);
-    light.setAlpha(0);
-    lg.setColorAt(0.0, light);
-    lg.setColorAt(1.0, light);
-    painter.setPen(QPen(lg,1));
-
-    painter.drawLine(QPointF(x, titleTop+titleHeight-0.5),
-                           QPointF(x+w, titleTop+titleHeight-0.5));
+        if (align & Qt::AlignLeft) {
+            int left = titleLeft + QFontMetrics(options()->font(isActive(), false)).width(caption());
+            int right = titleLeft + titleWidth;
+            drawScratch(&painter, palette, left, right, titleTop+6);
+        }
+        if (align & Qt::AlignRight) {
+            int left = titleLeft;
+            int right = titleLeft + titleWidth - QFontMetrics(options()->font(isActive(), false)).width(caption());
+            drawScratch(&painter, palette, right, left, titleTop+6);
+        }
+        if (align & Qt::AlignHCenter) {
+            int textWidth = QFontMetrics(options()->font(isActive(), false)).width(caption());
+            int left = titleLeft;
+            int centerLeft = titleLeft + titleWidth/2 - textWidth/2;
+            int centerRight = titleLeft + titleWidth/2 + textWidth/2;
+            int right = titleLeft + titleWidth;
+            drawScratch(&painter, palette, centerLeft, left, titleTop+6);
+            drawScratch(&painter, palette, centerRight, right, titleTop+6);
+        }
+    }
 
     // Draw shadows of the frame
     bool maximized = maximizeMode()==MaximizeFull && !options()->moveResizeMaximizedWindows();
@@ -369,6 +384,33 @@ void OxygenClient::paintEvent(QPaintEvent *e)
     renderDot(&painter, QPointF(6.5, 2.5), 1.8);
 }
 
+void OxygenClient::drawScratch(QPainter *p, QPalette &palette, const int start, const int end, const int topMargin)
+{
+    QLinearGradient scratchlg(QPoint(start,0), QPoint(end,0));
+    scratchlg.setColorAt(0.0, Qt::transparent);
+    scratchlg.setColorAt(0.05, KDecoration::options()->color(ColorTitleBar));
+    scratchlg.setColorAt(1.0, Qt::transparent);
+    QPen pen1(scratchlg, 0.5);
+
+    QLinearGradient scratchlg2(QPoint(start,0), QPoint(end,0));
+    scratchlg2.setColorAt(0.0, Qt::transparent);
+    scratchlg2.setColorAt(0.05, helper_.calcLightColor(palette.color(QPalette::Window)));
+    scratchlg2.setColorAt(1.0, Qt::transparent);
+    QPen pen2(scratchlg2, 0.5);
+
+    bool antialiasing = p->testRenderHint(QPainter::Antialiasing);
+    p->setRenderHint(QPainter::Antialiasing, false);
+    for (int i = 0; i < 3; ++i)
+    {
+        p->setPen(pen1);
+        p->drawLine(QPointF(start, topMargin+4*i), QPointF(end, topMargin+4*i));
+        p->setPen(pen2);
+        p->drawLine(QPointF(start, topMargin+4*i+1), QPointF(end, topMargin+4*i+1));
+    }
+    p->setRenderHint(QPainter::Antialiasing, antialiasing);
+}
+
+
 void OxygenClient::updateWindowShape()
 {
     bool maximized = maximizeMode()==MaximizeFull && !options()->moveResizeMaximizedWindows();
