@@ -24,15 +24,20 @@
 #include <QtCore/QObject>
 #include <QtCore/QStringList>
 
-#include <kgenericfactory.h>
+#include <KDE/KGenericFactory>
+#include <KDE/KService>
 
-#include <plasma/plasma_export.h>
+#include <plasma/version.h>
 #include <plasma/plasma.h>
 
 namespace Plasma
 {
 
 class DataContainer;
+class DataEngineScript;
+class Package;
+class Service;
+class DataEnginePrivate;
 
 /**
  * @class DataEngine
@@ -50,6 +55,11 @@ class DataContainer;
  **/
 class PLASMA_EXPORT DataEngine : public QObject
 {
+    friend class DataEnginePrivate;
+    friend class DataEngineScript;
+    friend class DataEngineManager;
+    friend class NullEngine;
+
     Q_OBJECT
     Q_PROPERTY( QStringList sources READ sources )
     Q_PROPERTY( bool valid READ isValid )
@@ -62,12 +72,22 @@ class PLASMA_EXPORT DataEngine : public QObject
         typedef QHash<QString, DataContainer*> SourceDict;
 
         /**
-         * Default constructor.
+         * Constructor.
          *
          * @param parent The parent object.
+         * @param service pointer to the service that describes the engine
          **/
-        explicit DataEngine(QObject* parent = 0);
-        virtual ~DataEngine();
+        explicit DataEngine(QObject* parent = 0, KService::Ptr service = KService::Ptr(0));
+        DataEngine(QObject* parent, const QVariantList& args);
+        ~DataEngine();
+
+        /**
+         * This method is called when the DataEngine is started. When this
+         * method is called the DataEngine is fully constructed and ready to be
+         * used. This method should be reimplemented by DataEngine subclasses
+         * which have the need to perform a startup routine.
+         **/
+        virtual void init();
 
         /**
          * @return a list of all the data sources available via this DataEngine
@@ -77,52 +97,72 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         virtual QStringList sources() const;
 
+        /**
+         * @param source the source to targe the Service at
+         * @return a Service that has the source as a destination. The service
+         *         is parented to the DataEngine, but may be deleted by the
+         *         caller when finished with it
+         */
+        virtual Service* serviceForSource(const QString &source);
+
+        /**
+         * Returns the engine name for the DataEngine
+         */
+        QString name() const;
+
         /**
          * Connects a source to an object for data updates. The object must
          * have a slot with the following signature:
          *
-         * updated(QString sourceName, Plasma::DataEngine::Data data)
+         * dataUpdated(const QString &sourceName, const Plasma::DataEngine::Data &data)
          *
          * The data is a QHash of QVariants keyed by QString names, allowing
          * one data source to provide sets of related data.
          *
          * @param source the name of the data source
          * @param visualization the object to connect the data source to
-         * @param updateInterval the frequency, in milliseconds, with which to signal updates;
+         * @param pollingInterval the frequency, in milliseconds, with which to check for updates;
          *                        a value of 0 (the default) means to update only
          *                        when there is new data spontaneously generated
          *                        (e.g. by the engine); any other value results in
          *                        periodic updates from this source. This value is
          *                        per-visualization and can be handy for items that require
          *                        constant updates such as scrolling graphs or clocks.
-         * @param intervalAlignedTo the number of ms to aling the interval to
+         *                        If the data has not changed, no update will be sent.
+         * @param intervalAlignment the number of ms to align the interval to
          **/
         Q_INVOKABLE void connectSource(const QString& source, QObject* visualization,
-                                       uint updateInterval = 0,
+                                       uint pollingInterval = 0,
                                        Plasma::IntervalAlignment intervalAlignment = NoAlignment) const;
 
         /**
-         * Connects all sources to an object for data updates. The object must
-         * have a slot with the following signature:
+         * Connects all currently existing sources to an object for data updates.
+         * The object must have a slot with the following signature:
          *
-         * SLOT(updated(QString, Plasma::DataEngine::Data))
+         * SLOT(dataUpdated(QString,Plasma::DataEngine::Data))
          *
          * The data is a QHash of QVariants keyed by QString names, allowing
          * one data source to provide sets of related data.
          *
          * This method may be called multiple times for the same visualization
-         * without side-effects. This can be useful to change the updateInterval.
+         * without side-effects. This can be useful to change the pollingInterval.
+         *
+         * Note that this method does not automatically connect sources that
+         * may appear later on. Connecting and responding to the sourceAdded sigal
+         * is still required to achieve that.
          *
          * @param visualization the object to connect the data source to
-         * @param updateInterval the frequency, in milliseconds, with which to signal updates;
+         * @param pollingInterval the frequency, in milliseconds, with which to check for updates;
          *                        a value of 0 (the default) means to update only
          *                        when there is new data spontaneously generated
          *                        (e.g. by the engine); any other value results in
          *                        periodic updates from this source. This value is
          *                        per-visualization and can be handy for items that require
          *                        constant updates such as scrolling graphs or clocks.
+         *                        If the data has not changed, no update will be sent.
+         * @param intervalAlignment the number of ms to align the interval to
          **/
-        Q_INVOKABLE void connectAllSources(QObject* viualization, uint updateInterval = 0,
+        Q_INVOKABLE void connectAllSources(QObject* visualization, uint pollingInterval = 0,
                                            Plasma::IntervalAlignment intervalAlignment = NoAlignment) const;
 
         /**
@@ -135,12 +175,12 @@ class PLASMA_EXPORT DataEngine : public QObject
 
         /**
          * Retrevies a pointer to the DataContainer for a given source. This method
-         * should not be used if possible. An exception is for script engines that 
+         * should not be used if possible. An exception is for script engines that
          * can not provide a QMetaObject as required by connectSource for the initial
-         * call to updated(). Using this method, such engines can provide their own
+         * call to dataUpdated. Using this method, such engines can provide their own
          * connectSource API.
          *
-         * @arg source the name of the source.
+         * @param source the name of the source.
          * @return pointer to a DataContainer, or zero on failure
          **/
         Q_INVOKABLE DataContainer* containerForSource(const QString &source);
@@ -157,34 +197,24 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         Q_INVOKABLE DataEngine::Data query(const QString& source) const;
 
-        /**
-         * Reference counting method. Calling this method increases the count
-         * by one.
-         **/
-        void ref();
-
-        /**
-         * Reference counting method. Calling this method decreases the count
-         * by one.
-         **/
-        void deref();
-
-        /**
-         * Reference counting method. Used to determine if this DataEngine is 
-         * used.
-         * @return true if the reference count is non-zero
-         **/
-        bool isUsed() const;
-
         /**
          * Returns true if this engine is valid, otherwise returns false
          **/
         bool isValid() const;
 
         /**
-         * Sets the icon for this data engine
-         **/
-        void setIcon(const QString& icon);
+         * Returns true if the data engine is empty, which is to say that it has no
+         * data sources currently.
+         */
+        bool isEmpty() const;
+
+        /**
+         * Returns the maximum number of sources this DataEngine will have
+         * at any given time.
+         *
+         * @return the maximum number of sources; zero means no limit.
+         */
+        uint maxSourceCount() const;
 
         /**
          * @return the name of the icon for this data engine; and empty string
@@ -192,12 +222,19 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         QString icon() const;
 
+        /**
+         * Accessor for the associated Package object if any.
+         *
+         * @return the Package object, or 0 if none
+         **/
+        const Package* package() const;
+
     Q_SIGNALS:
         /**
          * Emitted when a new data source is created
          * @param source the name of the new data source
          **/
-        void newSource(const QString& source);
+        void sourceAdded(const QString& source);
 
         /**
          * Emitted when a data source is removed.
@@ -206,21 +243,13 @@ class PLASMA_EXPORT DataEngine : public QObject
         void sourceRemoved(const QString& source);
 
     protected:
-        /**
-         * This method is called when the DataEngine is started. When this
-         * method is called the DataEngine is fully constructed and ready to be
-         * used. This method should be reimplemented by DataEngine subclasses
-         * which have the need to perform a startup routine.
-         **/
-        virtual void init();
-
         /**
          * When a source that does not currently exist is requested by the
          * consumer, this method is called to give the DataEngine the
          * opportunity to create one.
          *
          * The name of the data source (e.g. the source parameter passed into
-         * setData) it must be the same as the name passed to sourceRequested
+         * setData) must be the same as the name passed to sourceRequestEvent
          * otherwise the requesting visualization may not receive notice of a
          * data update.
          *
@@ -231,21 +260,22 @@ class PLASMA_EXPORT DataEngine : public QObject
          *
          *      setData(name, DataEngine::Data());
          *
+         * @param source the name of the source that has been requested
          * @return true if a DataContainer was set up, false otherwise
          */
-        virtual bool sourceRequested(const QString &name);
+        virtual bool sourceRequestEvent(const QString &source);
 
         /**
          * Called by internal updating mechanisms to trigger the engine
          * to refresh the data contained in a given source. Reimplement this
-         * method when using facilities such as setUpdateInterval.
-         * @see setUpdateInterval
+         * method when using facilities such as setPollingInterval.
+         * @see setPollingInterval
          *
          * @param source the name of the source that should be updated
          * @return true if the data was changed, or false if there was no
          *         change or if the change will occur later
          **/
-        virtual bool updateSource(const QString& source);
+        virtual bool updateSourceEvent(const QString& source);
 
         /**
          * Sets a value for a data source. If the source
@@ -276,11 +306,11 @@ class PLASMA_EXPORT DataEngine : public QObject
         void setData(const QString &source, const Data &data);
 
         /**
-         * Clears all the data associated with a data source.
+         * Removes all the data associated with a data source.
          *
          * @param source the name of the data source
          **/
-        void clearData(const QString& source);
+        void removeAllData(const QString& source);
 
         /**
          * Removes a data entry from a source
@@ -304,7 +334,7 @@ class PLASMA_EXPORT DataEngine : public QObject
          *
          * @param limit the maximum number of sources to keep active
          **/
-        void setSourceLimit(uint limit);
+        void setMaxSourceCount(uint limit);
 
         /**
          * Sets the minimum amount of time, in milliseconds, that must pass between
@@ -312,41 +342,41 @@ class PLASMA_EXPORT DataEngine : public QObject
          * due to multiple update requests coming in, which can be useful for
          * expensive (time- or resource-wise) update mechanisms.
          *
-         * @arg minimumMs the minimum time lapse, in milliseconds, between updates.
+         * @param minimumMs the minimum time lapse, in milliseconds, between updates.
          *                A value less than 0 means to never perform automatic updates,
          *                a value of 0 means update immediately on every update request,
          *                a value >0 will result in a minimum time lapse being enforced.
          **/
-        void setMinimumUpdateInterval(int minimumMs);
+        void setMinimumPollingInterval(int minimumMs);
 
         /**
-         * @return the minimum time between updates. @see setMinimumupdateInterval
+         * @return the minimum time between updates. @see setMinimumPollingInterval
          **/
-        int minimumUpdateInterval() const;
+        int minimumPollingInterval() const;
 
         /**
          * Sets up an internal update tick for all data sources. On every update,
-         * updateSource will be called for each applicable source.
-         * @see updateSource
+         * updateSourceEvent will be called for each applicable source.
+         * @see updateSourceEvent
          *
          * @param frequency the time, in milliseconds, between updates. A value of 0
          *                  will stop internally triggered updates.
          **/
-        void setUpdateInterval(uint frequency);
+        void setPollingInterval(uint frequency);
 
         /**
          * Returns the current update frequency.
-         * @see setUpdateInterval
+         * @see setPollingInterval
          NOTE: This is not implemented to prevent having to store the value internally.
                When there is a good use case for needing access to this value, we can
                add another member to the Private class and add this method.
-        uint updateInterval();
+        uint pollingInterval();
          **/
 
         /**
          * Removes all data sources
          **/
-        void clearSources();
+        void removeAllSources();
 
         /**
          * Sets whether or not this engine is valid, e.g. can be used.
@@ -360,20 +390,30 @@ class PLASMA_EXPORT DataEngine : public QObject
         /**
          * @return the list of active DataContainers.
          */
-        SourceDict sourceDict() const;
+        SourceDict containerDict() const;
 
         /**
          * Reimplemented from QObject
          **/
         void timerEvent(QTimerEvent *event);
 
+        /**
+         * Sets the engine name for the DataEngine
+         */
+        void setName(const QString &name);
+
+        /**
+         * Sets the icon for this data engine
+         **/
+        void setIcon(const QString& icon);
+
     protected Q_SLOTS:
         /**
          * Call this method when you call setData directly on a DataContainer instead
          * of using the DataEngine::setData methods.
-         * If this method is not called, no updated(..) signals will be emitted!
+         * If this method is not called, no dataUpdated(..) signals will be emitted!
          */
-        void checkForUpdates();
+        void scheduleSourcesUpdated();
 
         /**
          * Removes a data source.
@@ -381,25 +421,18 @@ class PLASMA_EXPORT DataEngine : public QObject
          **/
         void removeSource(const QString& source);
 
-        /**
-         * @internal
-         **/
-        void startInit();
-
-        /**
-         * @internal
-         **/
-        void internalUpdateSource(DataContainer* source);
-
     private:
-        class Private;
-        Private* const d;
+        Q_PRIVATE_SLOT(d, void internalUpdateSource(DataContainer* source))
+
+        DataEnginePrivate* const d;
 };
 
 } // Plasma namespace
 
 #define K_EXPORT_PLASMA_DATAENGINE(libname, classname) \
 K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
-K_EXPORT_PLUGIN(factory("plasma_engine_" #libname))
+K_EXPORT_PLUGIN(factory("plasma_engine_" #libname)) \
+K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+
 #endif // multiple inclusion guard
 
