@@ -27,15 +27,19 @@
 #include <KDE/KSharedConfig>
 
 #include <plasma/plasma_export.h>
+#include <plasma/packagestructure.h>
 
 namespace Plasma
 {
+
+class ThemePrivate;
+
 /**
  * @short Interface to the Plasma theme
  *
- * Accessed via Plasma::Theme::self() e.g:
+ * Accessed via Plasma::Theme::defaultTheme() e.g:
  * \code
- * QString image = Plasma::Theme::self()->image("widgets/clock")
+ * QString imagePath = Plasma::Theme::defaultTheme()->imagePath("widgets/clock")
  * \endcode
  *
  * Plasma::Theme provides access to a common and standardized set of graphic
@@ -52,10 +56,22 @@ class PLASMA_EXPORT Theme : public QObject
     Q_PROPERTY( QString themeName READ themeName )
 
     public:
+        enum ColorRole
+        {
+            TextColor = 0 /**<  the text color to be used by items resting on the background */,
+            HighlightColor = 1 /**<  the text higlight color to be used by items resting on the background */,
+            BackgroundColor = 2 /**< the default background color */
+        };
+
+        enum FontRole
+        {
+            DefaultFont = 0 /**< The standard text font */
+        };
+
         /**
          * Singleton pattern accessor
          **/
-        static Theme* self();
+        static Theme* defaultTheme();
 
         /**
          * Default constructor. Usually you want to use the singleton instead.
@@ -64,13 +80,9 @@ class PLASMA_EXPORT Theme : public QObject
         ~Theme();
 
         /**
-         * Sets the application the theme setting is associated with. This
-         * allows for individual applications that use libplasma to have the
-         * theme set independantly.
-         *
-         * @param appname name of the application
-         **/
-        void setApplication(const QString &appname);
+         * @return a package structure representing a Theme
+         */
+        static PackageStructure::Ptr packageStructure();
 
         /**
          * Sets the current theme being used.
@@ -89,47 +101,86 @@ class PLASMA_EXPORT Theme : public QObject
          *           ".svg" part or a leading slash)
          * @return the full path to the requested file for the current theme
          */
-        Q_INVOKABLE QString image( const QString& name ) const;
+        Q_INVOKABLE QString imagePath(const QString& name) const;
+
+        /**
+         * Retreives the default wallpaper associated with this theme.
+         * 
+         * @arg size the target height and width of the wallpaper; if an invalid size
+         *           is passed in, then a default size will be provided instead.
+         * @return the full path to the wallpaper image
+         */
+         Q_INVOKABLE QString wallpaperPath(const QSize &size = QSize()) const;
+
+        /**
+         * Checks if this theme has an image named in a certain way
+         *
+         * @arg name the name of the file in the theme directory (without the
+         *           ".svg" part or a leading slash)
+         * @return true if the image exists for this theme
+         */
+        Q_INVOKABLE bool currentThemeHasImage(const QString& name) const;
 
         /**
          * Returns the color scheme configurationthat goes along this theme.
          * This can be used with KStatefulBrush and KColorScheme to determine
          * the proper colours to use along with the visual elements in this theme.
          */
-        Q_INVOKABLE KSharedConfigPtr colors() const;
+        Q_INVOKABLE KSharedConfigPtr colorScheme() const;
 
         /**
          * Returns the text color to be used by items resting on the background
+         *
+         * @arg role which role (usage pattern) to get the color for
          */
-        Q_INVOKABLE QColor textColor() const;
-
-        /**
-         * Returns the background color to be used by items resting on the background
-         */
-        Q_INVOKABLE QColor backgroundColor() const;
+        Q_INVOKABLE QColor color(ColorRole role) const;
 
         /**
          * Sets the default font to be used with themed items. Defaults to
          * the application wide default font.
+         *
+         * @arg font the new font
+         * @arg role which role (usage pattern) to set the font for
          */
-        Q_INVOKABLE void setFont(const QFont &font);
+        Q_INVOKABLE void setFont(const QFont &font, FontRole role = DefaultFont);
 
         /**
          * Returns the font to be used by themed items
+         *
+         * @arg role which role (usage pattern) to get the font for
          */
-        Q_INVOKABLE QFont font() const;
+        Q_INVOKABLE QFont font(FontRole role) const;
 
         /**
          * Returns the font metrics for the font to be used by themed items
          */
         Q_INVOKABLE QFontMetrics fontMetrics() const;
 
+        /**
+         * Returns if the window manager effects (e.g. translucency, compositing) is active or not
+         */
+        Q_INVOKABLE bool windowTranslucencyEnabled() const;
+
+        /**
+         * Tells the theme whether to follow the global settings or use application
+         * specific settings
+         *
+         * @arg useGlobal pass in true to follow the global settings
+         */
+        void setUseGlobalSettings(bool useGlobal);
+
+        /**
+         * @return true if the global settings are followed, false if application
+         * specific settings are used.
+         */
+        bool useGlobalSettings() const;
+
     Q_SIGNALS:
         /**
          * Emitted when the user changes the theme. SVGs should be reloaded at
          * that point
          */
-        void changed();
+        void themeChanged();
 
     public Q_SLOTS:
         /**
@@ -139,8 +190,11 @@ class PLASMA_EXPORT Theme : public QObject
         void settingsChanged();
 
     private:
-        class Private;
-        Private* const d;
+        friend class ThemeSingleton;
+        friend class ThemePrivate;
+        ThemePrivate* const d;
+
+        Q_PRIVATE_SLOT(d, void compositingChanged())
 };
 
 } // Plasma namespace
