@@ -24,52 +24,64 @@
 #include <QGraphicsItem>
 #include <QEvent>
 #include <QMimeData>
+#include <QGraphicsLinearLayout>
 
 #include <KGlobalSettings>
 #include <KDebug>
-#include <KLocale>
+#include <KDesktopFile>
 #include <KIconLoader>
-#include <KMimeType>
+#include <KLocale>
+#include <KMenu>
 #include <KPropertiesDialog>
 #include <KRun>
 #include <KSharedConfig>
-#include <KUrl>
-#include <KDesktopFile>
 #include <KShell>
-#include <KMenu>
+#include <KUrl>
+#include <KWindowSystem>
 #include <kio/copyjob.h>
+#include <kio/netaccess.h>
 
 #include <plasma/theme.h>
-#include <plasma/layouts/boxlayout.h>
 #include <plasma/widgets/icon.h>
 #include <plasma/containment.h>
 
 IconApplet::IconApplet(QObject *parent, const QVariantList &args)
     : Plasma::Applet(parent, args),
-      m_dialog(0)
+      m_dialog(0),
+      m_mimetype(0)
 {
     setAcceptDrops(true);
+    setBackgroundHints(NoBackground);
     setHasConfigurationInterface(true);
     m_icon = new Plasma::Icon(this);
-    m_icon->setDrawBackground(true);
 
-    if (args.count() > 2) {
-        setUrl(args.at(2).toString());
+    if (args.count() > 0) {
+        setUrl(args.value(0).toString());
+        m_icon->setText(m_text);
     }
+
+    resize(m_icon->sizeFromIconSize(IconSize(KIconLoader::Desktop)));
+    //kDebug() << "sized to:" << geometry();
 }
 
 void IconApplet::init()
 {
-    KConfigGroup cg = config();
-    //setMinimumSize(QSize(48,68));
+    QGraphicsLinearLayout *layout = new QGraphicsLinearLayout(this);
+    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setSpacing(0);
 
-    connectMouseSlots();
-    setUrl(cg.readEntry("Url", m_url));
-    setDrawStandardBackground(false);
+    layout->addItem(m_icon);
+
+    KConfigGroup cg = config();
+
+    if (!m_url.isValid()) {
+        setUrl(cg.readEntry("Url", m_url));
+    }
     setDisplayLines(2);
 
-    m_icon->installSceneEventFilter(this);
-    m_icon->resize(contentSize());
+    registerAsDragHandle(m_icon);
+
+    setAspectRatioMode(Plasma::ConstrainedSquare);
 
     // we do this right away since we may have our config
     // read shortly by the containment. usually applets don't need
@@ -87,17 +99,16 @@ IconApplet::~IconApplet()
     delete m_dialog;
 }
 
-void IconApplet::saveState(KConfigGroup *cg) const
+void IconApplet::saveState(KConfigGroup &cg) const
 {
-    cg->writeEntry("Url", m_url);
+    cg.writeEntry("Url", m_url);
 }
 
 void IconApplet::setUrl(const KUrl& url)
 {
-    m_url = url;
+    m_url = KIO::NetAccess::mostLocalUrl(url, 0);
 
-    KMimeType::Ptr mime = KMimeType::findByUrl(url);
-    m_mimetype = mime->name();
+    m_mimetype = KMimeType::findByUrl(url);
 
     if (m_url.isLocalFile() && KDesktopFile::isDesktopFile(m_url.toLocalFile())) {
         KDesktopFile f(m_url.toLocalFile());
@@ -122,37 +133,39 @@ void IconApplet::setUrl(const KUrl& url)
 void IconApplet::openUrl()
 {
     if (m_url.isValid()) {
-        if (containment()) {
-            containment()->emitLaunchActivated();
-        }
-        KRun::runUrl(m_url, m_mimetype, 0);
+        emit releaseVisualFocus();
+        KRun::runUrl(m_url, m_mimetype->name(), 0);
     }
 }
 
-void IconApplet::constraintsUpdated(Plasma::Constraints constraints)
+void IconApplet::constraintsEvent(Plasma::Constraints constraints)
 {
-    setDrawStandardBackground(false);
+    setBackgroundHints(NoBackground);
 
     if (constraints & Plasma::FormFactorConstraint) {
+        disconnect(m_icon, SIGNAL(activated()), this, SLOT(openUrl()));
+        disconnect(m_icon, SIGNAL(clicked()), this, SLOT(openUrl()));
+
         if (formFactor() == Plasma::Planar ||
             formFactor() == Plasma::MediaCenter) {
+            connect(m_icon, SIGNAL(activated()), this, SLOT(openUrl()));
             m_icon->setText(m_text);
-            setMinimumContentSize(m_icon->sizeFromIconSize(IconSize(KIconLoader::Desktop)));
-            m_icon->setToolTip(Plasma::ToolTipData());
+            //FIXME TOOL TIP MANAGER
+            //m_icon->setToolTip(Plasma::ToolTipData());
+            m_icon->setDrawBackground(true);
         } else {
-            m_icon->setText(0);
-            setMinimumContentSize(m_icon->sizeFromIconSize(IconSize(KIconLoader::Panel)));
-            Plasma::ToolTipData data;
+            //in the panel the icon behaves like a button
+            connect(m_icon, SIGNAL(clicked()), this, SLOT(openUrl()));
+            m_icon->setText(QString());
+            //FIXME PORT TO TOOL TIP MANAGER
+            /*Plasma::ToolTipData data;
             data.mainText = m_text;
             data.subText = m_genericName;
             data.image = m_icon->icon().pixmap(IconSize(KIconLoader::Desktop));
-            m_icon->setToolTip(data);
+            m_icon->setToolTip(data);*/
+            m_icon->setDrawBackground(false);
         }
     }
-
-    if (constraints & Plasma::SizeConstraint) {
-        m_icon->resize(contentSize());
-    }
 }
 
 void IconApplet::showConfigurationInterface()
@@ -161,17 +174,12 @@ void IconApplet::showConfigurationInterface()
         m_dialog = new KPropertiesDialog(m_url, 0 /*no parent widget*/);
         connect(m_dialog, SIGNAL(applied()), this, SLOT(acceptedPropertiesDialog()));
         connect(m_dialog, SIGNAL(propertiesClosed()), this, SLOT(propertiesDialogClosed()));
+        m_dialog->show();
+    } else {
+        KWindowSystem::setOnDesktop(m_dialog->winId(), KWindowSystem::currentDesktop());
+        m_dialog->show();
+        KWindowSystem::activateWindow(m_dialog->winId());
     }
-
-    m_dialog->show();
-}
-
-QSizeF IconApplet::sizeHint() const
-{
-    QSizeF iconSize = m_icon->sizeHint();
-    qreal width = qBound(minimumSize().width(), iconSize.width(), maximumSize().width());
-    qreal height = qBound(minimumSize().height(), iconSize.height(), maximumSize().height());
-    return QSizeF(width,height);
 }
 
 void IconApplet::setDisplayLines(int displayLines)
@@ -184,6 +192,7 @@ void IconApplet::setDisplayLines(int displayLines)
         update();
     }
 }
+
 int IconApplet::displayLines()
 {
     if (m_icon) {
@@ -208,22 +217,11 @@ void IconApplet::propertiesDialogClosed()
 
 void IconApplet::dropEvent(QGraphicsSceneDragDropEvent *event)
 {
-   if (!KUrl::List::canDecode(event->mimeData())) {
-       return;
-   }
-
-    //FIXME: this hacky workaround must go away when KUrl::List::fromMimeData(event->mimeData()); will be fixed
-    QString payload = event->mimeData()->text();
-    if (payload.isEmpty()) {
+    if (!KUrl::List::canDecode(event->mimeData())) {
         return;
     }
-    KUrl::List urls(payload.split("\n"));
 
-    //if there are more than one the last is junk
-    if (urls.count() > 1) {
-        urls.removeLast();
-    }
-    //KUrl::List urls = KUrl::List::fromMimeData(event->mimeData());
+    KUrl::List urls = KUrl::List::fromMimeData(event->mimeData());
 
     if (urls.count() > 0) {
         event->accept();
@@ -234,19 +232,21 @@ void IconApplet::dropEvent(QGraphicsSceneDragDropEvent *event)
 
     if (m_url.isEmpty()) {
         setUrl(urls.first());
-        constraintsUpdated(Plasma::FormFactorConstraint);
+        //TODO: why we don't call updateConstraints()?
+        constraintsEvent(Plasma::FormFactorConstraint);
     } else if (m_url.isLocalFile() &&
-              (m_mimetype == "application/x-executable" ||
-                m_mimetype == "application/x-shellscript" ||
+              (m_mimetype &&
+               m_mimetype->is("application/x-executable") ||
+               m_mimetype->is("application/x-shellscript") ||
                 KDesktopFile::isDesktopFile(m_url.toLocalFile()))) {
 
         //Parameters
         QString params;
-        foreach (KUrl url, urls) {
+        foreach (const KUrl &url, urls) {
             if (url.isLocalFile()) {
-                params += " " + KShell::quoteArg(url.path());
+                params += ' ' + KShell::quoteArg(url.path());
             } else {
-                params += " " + KShell::quoteArg(url.prettyUrl());
+                params += ' ' + KShell::quoteArg(url.prettyUrl());
             }
         }
 
@@ -270,7 +270,7 @@ void IconApplet::dropEvent(QGraphicsSceneDragDropEvent *event)
 
                 KUrl dest(path);
                 KMimeType::Ptr mime = KMimeType::findByUrl(dest);
-                if (mime->is("inode/directory")) {
+                if (m_mimetype->is("inode/directory")) {
                     dropUrls(urls, dest, event->modifiers());
                 }
             }
@@ -279,53 +279,17 @@ void IconApplet::dropEvent(QGraphicsSceneDragDropEvent *event)
             commandStr = KShell::quoteArg(m_url.path());
         }
 
-        KRun::runCommand(commandStr + " " + params, 0);
-    } else if (m_mimetype == "inode/directory") {
+        KRun::runCommand(commandStr + ' ' + params, 0);
+    } else if (m_mimetype->is("inode/directory")) {
         dropUrls(urls, m_url, event->modifiers());
     }
 }
 
-Qt::Orientations IconApplet::expandingDirections() const
+QPainterPath IconApplet::shape() const
 {
-    return 0;
+    return m_icon->shape();
 }
 
-bool IconApplet::sceneEventFilter( QGraphicsItem * watched, QEvent * event )
-{
-    switch (event->type()) {
-        case QEvent::GraphicsSceneMouseMove: {
-            mouseMoveEvent(static_cast<QGraphicsSceneMouseEvent*>(event));
-            break;
-        }
-
-        default:
-            break;
-    }
-
-    return QGraphicsItem::sceneEventFilter(watched, event);
-}
-
-void IconApplet::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
-{
-    QPointF curPos = transform().map(event->pos());
-    QPointF lastPos = transform().map(event->lastPos());
-    QPointF delta = curPos-lastPos;
-
-    if (!isImmutable() && formFactor() == Plasma::Planar) {
-        QGraphicsItem *parent = parentItem();
-        Plasma::Applet *applet = qgraphicsitem_cast<Plasma::Applet*>(parent);
-
-        if (applet && applet->isContainment()) {
-            // our direct parent is a containment. just move ourselves.
-            moveBy(delta.x(),delta.y());
-        } else if (parent) {
-            //don't move the icon as well because our parent (usually an appletHandle) will do it for us
-            parent->moveBy(delta.x(),delta.y());
-        }
-    }
-}
-
-
 //dropUrls from DolphinDropController
 void IconApplet::dropUrls(const KUrl::List& urls,
                           const KUrl& destination,
@@ -411,16 +375,5 @@ void IconApplet::dropUrls(const KUrl::List& urls,
     }
 }
 
-void IconApplet::connectMouseSlots()
-{
-    if(KGlobalSettings::singleClick()) {
-        //kDebug() << "Single-Click initialized.";
-        connect(m_icon, SIGNAL(clicked()), this, SLOT(openUrl()));
-    } else {
-        //kDebug() << "Double-Click initialized.";
-        connect(m_icon, SIGNAL(doubleClicked()), this, SLOT(openUrl()));
-    }
-}
-
 #include "icon.moc"
 
