@@ -20,6 +20,7 @@
 #include "ui_BackgroundDialog.h"
 
 class BackgroundContainer;
+class ThemeModel;
 class BackgroundListModel;
 class QComboBox;
 class QLabel;
@@ -37,16 +38,18 @@ Q_OBJECT
 public:
     enum BackgroundMode {
         kStaticBackground,
-        kSlideshowBackground
+        kSlideshowBackground,
+        kNoBackground
     };
     
-    // FIXME seems that we're leaking, make a distructor
+    // FIXME seems that we're leaking, make a destructor
     BackgroundDialog(const QSize &res, 
                      const KConfigGroup &config,
+                     const KConfigGroup &globalConfig,
                      QWidget *parent = 0);
     
-    void reloadConfig(const KConfigGroup &config);
-    void saveConfig(KConfigGroup config);
+    void reloadConfig(const KConfigGroup &config, const KConfigGroup &globalConfig);
+    void saveConfig(KConfigGroup config, KConfigGroup globalConfig);
     
     QString path() const;
     int mode();
@@ -54,6 +57,7 @@ private:
     //QComboBox *m_mode;
     //QComboBox *m_view;
     BackgroundListModel *m_model;
+    ThemeModel *m_themeModel;
     
     //QLabel *m_authorLabel;
     //QLabel *m_emailLabel;
@@ -96,9 +100,11 @@ private:
     virtual bool contains(const QString &path) const;
 private slots:
     void update();
-    void getNewStuff();
+    void getNewWallpaper();
+    void getNewThemes();
     void browse();
     void showFileDialog();
+    void enableButtons(bool enabled);
     
     void slotAddDir();
     void slotRemoveDir();
